This crate contains kube-rs compatible bindings for Kubernetes custom resources for the clusters.clusternet.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
clusters.clusternet.io/v1beta1
ClusterRegistrationRequestManagedCluster